# Adjeff
<p align="center">
  <img src="https://github.com/walcark/Adjeff/actions/workflows/ci.yml/badge.svg">
  <a href="https://pixi.sh"><img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/prefix-dev/pixi/main/assets/badge/v0.json"></a>
  <a href="https://github.com/astral-sh/ruff"><img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json"></a>
  <a href="https://test.pypi.org/project/adjeff/"><img src="https://img.shields.io/badge/TestPyPI-adjeff-blue"></a>
  <img src="https://img.shields.io/github/license/walcark/Adjeff">
  <img src="https://img.shields.io/badge/python-3.10%2B-blue">
</p>

<p align="center">
  Utilities to simulate adjacency effects and improve atmospheric correction of satellite imagery (Sentinel-2).
</p>
